#!/bin/sh
#
# Copyright (c) 2013-2016 Linagora
#
# This program/library is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 2.1 of the License, or (at your
# option) any later version.
#
# This program/library is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
# for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program/library; If not, see http://www.gnu.org/licenses/
# for the GNU Lesser General Public License version 2.1.
#
#############################################################################
#
#                   Petals Registry Overlay Bootstrap Script
#
# Environment variables:
#
#  JAVA_HOME         Directory containing the JRE. Use the java executable
#                    found in $PATH if not defined.
#
#  JAVA_OPTS         Options for the JVM. Try "java -h" to get informations
#                    about the available options for your environment
#
#
#############################################################################

# Extra checks
set -eu

# Let's work directly in the distribution folder to avoid space in names if there is
BASEDIR="$(dirname "$0")/../"
cd "$BASEDIR"

# Set the path to the java executable
JAVA="${JAVA_HOME:-}/bin/java"
[ -x "$JAVA" ] || JAVA="$(which java)" || {
	echo "ERROR: java executable not found" >&2
	exit 1
}

PETALS_LIB_DIR="./lib"

# Set the path to petals bootstrap jar
PETALS_BOOTSTRAP_JAR_NAME="petals-registry-overlay.jar"
PETALS_JAR="$PETALS_LIB_DIR/$PETALS_BOOTSTRAP_JAR_NAME"
[ -f "$PETALS_JAR" ] || {
	echo "ERROR: $PETALS_BOOTSTRAP_JAR_NAME: JAR archive not found" >&2
	exit 1
}


# Adapt pathes if architecture is Cygwin
case "`uname`" in
	CYGWIN*)
		JAVA="$(cygpath --unix $JAVA)"
		PETALS_LIB_DIR="$(cygpath --dos $PETALS_LIB_DIR)"
		PETALS_JAR="$(cygpath --unix $PETALS_JAR)"
		;;
esac

# let's remember the current value if it's set, we will put it AFTER the one from env.sh
# to have the original one override it.
ORIGINAL_JAVA_OPTS=${JAVA_OPTS:-}

# set JAVA_OPTS for env.sh to have a value because we are in strict mode
JAVA_OPTS=""

ENV_FILE="./conf/env.sh"
if [ -f "$ENV_FILE" ]; then
   . "$ENV_FILE"
fi

JAVA_OPTS="$JAVA_OPTS -Djava.util.logging.manager=org.ow2.petals.registry_overlay.util.PetalsLogManager"

# Start
exec "$JAVA" -cp ${PETALS_CLASSPATH:-}:$PETALS_JAR $JAVA_OPTS $ORIGINAL_JAVA_OPTS org.ow2.petals.registry_overlay.Main "$@"
